Stan Math Library: stan/math/prim/scal/meta/index_type.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

index_type.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_META_INDEX_TYPE_HPP
2 #define STAN_MATH_PRIM_SCAL_META_INDEX_TYPE_HPP
3
4 namespace stan {
5
6 namespace math {
7
18 template <typename T>
19 struct index_type {
20 };
21
22
29 template <typename T>
30 struct index_type<const T> {
31 typedef typename index_type<T>::type type;
32 };
33
34 }
35 }
36
37
38 #endif
stan
Definition: log_sum_exp.hpp:8
stan::math::index_type
Primary template class for the metaprogram to compute the index type of a container.
Definition: index_type.hpp:19
stan::math::index_type< const T >::type
index_type< T >::type type
Definition: index_type.hpp:31

[ Stan Home Page ] © 2011–2016, Stan Development Team.